<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reset Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'reset' => 'Votre mot de passe a été réinitialisé !',
    'sent' => 'Nous vous avons envoyé par courriel le lien de réinitialisation du mot de passe.',
    'token' => 'Ce jeton de réinitialisation du mot de passe n’est pas valide.',
    'user' => 'Si l’adresse email que vous avez entrée existe dans notre base de données, un couriel de réinitialisation du mot de passe vous a été envoyé.',
    'changed' => 'Mot de passe changé avec succès.',
    'invalid' => 'Le mot de passe que vous avez saisi est incorrect.',
    'throttled' => 'Merci de patienter avant de réessayer.',

];
